<?php


if ( ! function_exists( 'tt_themeton_theme_setup' ) ) :
    function tt_themeton_theme_setup() {

        // load translate file
        load_theme_textdomain( 'themeton', get_template_directory() . '/languages' );

        // Add default posts and comments RSS feed links to head.
        add_theme_support( 'automatic-feed-links' );

        // Let WordPress manage the document title.
        add_theme_support( 'title-tag' );

        // Enable support for Post Thumbnails on posts and pages.
        add_theme_support( 'post-thumbnails' );
        set_post_thumbnail_size( 640, 380, true );

        // Set Image sizes
        add_image_size( 'post-thumb', 818, 390, true );

        // Set Image sizes
        add_image_size( 'blog-thumb', 370, 266, true );
        add_image_size( 'woo-thumb', 140, 207, true );
        add_image_size( 'folio-thumb', 271, 320, true );
        add_image_size( 'blog-small-thumb', 82, 72, true );

        // Set Image sizes
        add_image_size( 'process-thumb', 64, 64, true );
        add_image_size( 'testimonial-thumb', 100, 100, true );
        add_image_size( 'team-member', 274, 358, true );

        // This theme uses wp_nav_menu() in two locations.
        register_nav_menus( array(
            'primary' => __( 'Primary Menu', 'themeton' )
        ) );

        // Switch default core markup for search form, comment form, and comments to output valid HTML5.
        add_theme_support( 'html5', array(
            'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
        ) );

        // Enable support for Post Formats.
        /*add_theme_support( 'post-formats', array(
            'image', 'quote', 'gallery', 'audio'
        ) );*/

    }
endif;
add_action( 'after_setup_theme', 'tt_themeton_theme_setup' );


// default content width
if ( ! isset( $content_width ) ) $content_width = 940;



$tt_sidebars = array();
$tt_sidebars = array_merge(array(
    'sidebar'=> __('Post Sidebar Area', 'themeton'),
    'sidebar-page'=> __('Page Sidebar Area', 'themeton'),
    'sidebar-portfolio'=> __('Portfolio Sidebar Area', 'themeton'),
    'sidebar-woo'=> __('Woocommerce Sidebar Area', 'themeton')
), $tt_sidebars);

// Register widget area.
function tt_theme_widgets_init() {
    
    global $tt_sidebars;
    if(isset($tt_sidebars)) {
        foreach ($tt_sidebars as $id => $sidebar) {
            if( !empty($id) ){
                if( $id=='sidebar-portfolio' && !class_exists('TT_Portfolio_PT') )
                    continue;
                
                register_sidebar(array(
                    'name' => $sidebar,
                    'id' => $id,
                    'description' => __( 'Add widgets here to appear in your sidebar.', 'themeton' ),
                    'before_widget' => '<div id="%1$s" class="widget row %2$s">',
                    'after_widget'  => '</div>',
                    'before_title'  => '<h4 class="widget_title">',
                    'after_title'   => '</h4>'
                ));                
            }
        }
    }


    // Footer widget areas
    $footer_widget_num = TT::get_mod('footer_widget_num');

    for($i=1; $i<=$footer_widget_num ; $i++ ) {
        register_sidebar(
            array(
                'name'          => __( 'Footer Column', 'themeton' ) . ' ' .$i,
                'id'            => 'footer'.$i,
                'description'   => __( 'Add widgets here to appear in your footer column', 'themeton' ) . ' ' .$i,
                'before_widget' => '<div id="%1$s" class="footer_widget widget %2$s">',
                'after_widget'  => '</div>',
                'before_title'  => '<h4 class="title">',
                'after_title'   => '</h4>',
            )
        );
    }

    // Sub Footer Bar Content
    register_sidebar(
        array(
            'name'          => __( 'Sub Footer Content', 'themeton' ),
            'id'            => 'sub-footer-content',
            'description'   => __('Add widgets here to appear in your sub footer. Try to add simple widgets as possible and high and advanced widgets improper practically.', 'themeton'),
            'before_widget' => '<div id="%1$s" class="row m0 widget %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '',
            'after_title'   => '',
        )
    );
}

add_action( 'widgets_init', 'tt_theme_widgets_init' );



if ( ! function_exists( 'tt_theme_fonts_url' ) ) :
    function tt_theme_fonts_url() {
        $fonts_url = '';
        $fonts     = array();
        $subsets   = 'latin,latin-ext';

        // $fonts[] = 'Montserrat:400,700';
        // $fonts[] = 'Droid+Serif:400,700,400italic,700italic';
        // $fonts[] = 'Cabin:400,500,600,700,400italic,500italic,600italic,700italic';

        if ( $fonts ) {
            $fonts_url = esc_url(add_query_arg( array(
                'family' => implode( '|', $fonts ),
                'subset' => urlencode( $subsets ),
            ), '//fonts.googleapis.com/css' ));
        }

        return $fonts_url;
    }
endif;





function tt_theme_enqueue_scripts() {
    wp_enqueue_script( 'jquery' );
    wp_enqueue_script( 'wp-mediaelement' );

    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }

    // Add custom fonts, used in the main stylesheet.
    wp_enqueue_style( 'theme-fonts', tt_theme_fonts_url(), array(), null );

    wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap.min.css' );
    wp_enqueue_style( 'bootstrap-theme', get_template_directory_uri() . '/css/bootstrap-theme.min.css' );
    wp_enqueue_style( 'fontawesome', get_template_directory_uri() . '/css/font-awesome.min.css' );
    wp_enqueue_style( 'owl-carousel', get_template_directory_uri() . '/vendors/owl.carousel/css/owl.carousel.min.css' );
    wp_enqueue_style( 'owl-carousel-theme', get_template_directory_uri() . '/vendors/owl.carousel/css/owl.theme.default.min.css' );
    wp_enqueue_style( 'flelxslider', get_template_directory_uri() . '/vendors/flexslider/flexslider.css' );
    wp_enqueue_style( 'bootstrap-select', get_template_directory_uri() . '/vendors/bootstrap-select/css/bootstrap-select.min.css' );

    
    wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/js/bootstrap.min.js', false, false, true );
    wp_enqueue_script( 'owl-carousel', get_template_directory_uri() . '/vendors/owl.carousel/js/owl.carousel.min.js', false, false, true );
    wp_enqueue_script( 'bootstrap-select', get_template_directory_uri() . '/vendors/bootstrap-select/js/bootstrap-select.min.js', false, false, true );
    wp_enqueue_script( 'flexslider', get_template_directory_uri() . '/vendors/flexslider/jquery.flexslider-min.js', false, false, true );
    wp_enqueue_script( 'js-counter', get_template_directory_uri() . '/vendors/counterup/jquery.counterup.min.js', false, false, true );
    wp_enqueue_script( 'waypoints', get_template_directory_uri() . '/vendors/waypoints/waypoints.min.js', false, false, true );
    wp_enqueue_script( 'isotope', get_template_directory_uri() . '/vendors/isotope/isotope-custom.js', false, false, true );
    wp_enqueue_script( 'theme-script', get_template_directory_uri() . '/js/theme.js', false, false, true );

    wp_enqueue_style( 'theme-stylesheet', get_stylesheet_uri() );

    
}
add_action( 'wp_enqueue_scripts', 'tt_theme_enqueue_scripts' );


add_filter( 'body_class', 'tt_body_class_filter' );
function tt_body_class_filter( $classes ) {
    
    if( TT::get_mod('boxed') == '1'){
        $classes[] = 'boxed';
    }
    return $classes;
}


function custom_excerpt_length( $length ) {
    return 20;
}
add_filter( 'excerpt_length', 'custom_excerpt_length', 999 );


function custom_excerpt_more( $excerpt ) {
    return ' ...';
}
add_filter( 'excerpt_more', 'custom_excerpt_more' );


function tt_mime_types($mime_types){
    $mime_types['svg'] = 'image/svg+xml';
    return $mime_types;
}
add_filter('upload_mimes', 'tt_mime_types', 1, 1);





function tt_primary_callback(){
    echo '<ul class="nav navbar-nav">';
    wp_list_pages( array(
        'sort_column'  => 'menu_order, post_title',
        'title_li' => '') );
    echo '</ul>';
}




/*
                                                                    
 _____ _                 _              _____ _                     
|_   _| |_ ___ _____ ___| |_ ___ ___   |     | |___ ___ ___ ___ ___ 
  | | |   | -_|     | -_|  _| . |   |  |   --| | .'|_ -|_ -| -_|_ -|
  |_| |_|_|___|_|_|_|___|_| |___|_|_|  |_____|_|__,|___|___|___|___|
  
*/
  // Themeton Standard Package
require_once get_template_directory() . '/framework/classes/class.themeton.std.php';

// Include current theme customize
require_once TT::file_require(get_template_directory() . '/includes/functions.php');





// Print Favicon
add_action('wp_head', 'tt_print_favicon');
function tt_print_favicon(){
    if(TT::get_mod('favicon') != '')
        echo '<link rel="shortcut icon" type="image/x-icon" href="'.TT::get_mod('favicon').'"/>';
}

// Prints Custom Logo Image for Login Page
add_action('login_head', 'custom_login_logo');
function custom_login_logo() {
    $logo = TT::get_mod('logo_admin');
    if (!empty($logo)) {
        $logo = str_replace('[site_url]', site_url(), $logo);
        echo '<style type="text/css">.login h1 a { background: url(' . $logo . ') center center no-repeat !important;width: auto !important;}</style>';
    }
}



?>